pub struct DoFinallyBuilder { /* private fields */ }Expand description
Builder for a .do_finally() … .end_do_finally() block.
Implementations
Sourceimpl DoFinallyBuilder
impl DoFinallyBuilder
Sourcepub fn process(self, processor: BoxProcessor) -> Self
pub fn process(self, processor: BoxProcessor) -> Self
Add a step to the finally block.
Sourcepub fn on_when(self, predicate: FilterPredicate) -> Self
pub fn on_when(self, predicate: FilterPredicate) -> Self
Set an optional predicate that gates whether the finally block runs.
Sourcepub fn end_do_finally(self) -> DoTryBuilder
pub fn end_do_finally(self) -> DoTryBuilder
Close the finally block and return the parent DoTryBuilder.