pub struct FilterInSplitBuilder { /* private fields */ }Expand description
Builder for a filter scope nested inside a .split() block.
Implementations
Sourceimpl FilterInSplitBuilder
impl FilterInSplitBuilder
Sourcepub fn end_filter(self) -> SplitBuilder
pub fn end_filter(self) -> SplitBuilder
Close the filter scope and return the parent SplitBuilder.